==> haskell-crypto-pubkey-0.2.8-14-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-crypto-pubkey.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-pubkey
version: 0.2.8
id: crypto-pubkey-0.2.8-54qY7UbTDBW2jqv4mKOSxa
key: crypto-pubkey-0.2.8-54qY7UbTDBW2jqv4mKOSxa
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
homepage: https://github.com/vincenthz/hs-crypto-pubkey
synopsis: Public Key cryptography
description:
    Public Key cryptography
    .
    Supports RSA PKCS15, RSA OAEP, RSA PSS, DSA, ElGamal signature.
    .
    Also have primitive support for Diffie Hellman, and ElGamal encryption
category: Cryptography
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Crypto.PubKey.RSA Crypto.PubKey.RSA.PKCS15 Crypto.PubKey.RSA.OAEP
    Crypto.PubKey.RSA.PSS Crypto.PubKey.RSA.Prim Crypto.PubKey.DSA
    Crypto.PubKey.DH Crypto.PubKey.HashDescr
    Crypto.PubKey.MaskGenFunction Crypto.PubKey.ECC.Generate
    Crypto.PubKey.ECC.Prim Crypto.PubKey.ECC.DH Crypto.PubKey.ECC.ECDSA
hidden-modules: Crypto.PubKey.ElGamal Crypto.PubKey.RSA.Types
                Crypto.PubKey.Internal
abi: 32068631088232f1f334cd9f1776b1e7
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/crypto-pubkey-0.2.8
library-dirs: /usr/lib/ghc-8.0.1/site-local/crypto-pubkey-0.2.8
data-dir: /usr/share/arm-linux-ghc-8.0.1/crypto-pubkey-0.2.8
hs-libraries: HScrypto-pubkey-0.2.8-54qY7UbTDBW2jqv4mKOSxa
depends:
    base-4.9.0.0 byteable-0.1.1-15aIBCArSOBEnGxArzrDTM
    bytestring-0.10.8.1 crypto-numbers-0.2.7-BRqQYMaa83V13FdQ18ZcJz
    crypto-pubkey-types-0.4.3-922u6d7ABSC4wKGsJVnvgY
    crypto-random-0.0.9-JfzVLczngOAFA5qyobjUJe
    cryptohash-0.11.9-6k6h6rgW6V32279r46VuUC
haddock-interfaces: /usr/share/doc/haskell-crypto-pubkey/html/crypto-pubkey.haddock
haddock-html: /usr/share/doc/haskell-crypto-pubkey/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypto-pubkey-0.2.8-16-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-crypto-pubkey.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-pubkey
version: 0.2.8
id: crypto-pubkey-0.2.8-6SGrbpSPgDbEs7mLBP90G7
key: crypto-pubkey-0.2.8-6SGrbpSPgDbEs7mLBP90G7
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
homepage: https://github.com/vincenthz/hs-crypto-pubkey
synopsis: Public Key cryptography
description:
    Public Key cryptography
    .
    Supports RSA PKCS15, RSA OAEP, RSA PSS, DSA, ElGamal signature.
    .
    Also have primitive support for Diffie Hellman, and ElGamal encryption
category: Cryptography
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Crypto.PubKey.RSA Crypto.PubKey.RSA.PKCS15 Crypto.PubKey.RSA.OAEP
    Crypto.PubKey.RSA.PSS Crypto.PubKey.RSA.Prim Crypto.PubKey.DSA
    Crypto.PubKey.DH Crypto.PubKey.HashDescr
    Crypto.PubKey.MaskGenFunction Crypto.PubKey.ECC.Generate
    Crypto.PubKey.ECC.Prim Crypto.PubKey.ECC.DH Crypto.PubKey.ECC.ECDSA
hidden-modules: Crypto.PubKey.ElGamal Crypto.PubKey.RSA.Types
                Crypto.PubKey.Internal
abi: f5ab2c2a53be5868a9bd97d377dc1275
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/crypto-pubkey-0.2.8
library-dirs: /usr/lib/ghc-8.0.1/site-local/crypto-pubkey-0.2.8
data-dir: /usr/share/arm-linux-ghc-8.0.1/crypto-pubkey-0.2.8
hs-libraries: HScrypto-pubkey-0.2.8-6SGrbpSPgDbEs7mLBP90G7
depends:
    base-4.9.0.0 byteable-0.1.1-15aIBCArSOBEnGxArzrDTM
    bytestring-0.10.8.1 crypto-numbers-0.2.7-FzmArf9B7wj5kNgx5b2Eh1
    crypto-pubkey-types-0.4.3-KExqsYsa4Nq48VdVoHvzmy
    crypto-random-0.0.9-3zvdivDjLYjKUl1xLqa94x
    cryptohash-0.11.9-K1mrjHdP3V8CpgLjXvYwEM
haddock-interfaces: /usr/share/doc/haskell-crypto-pubkey/html/crypto-pubkey.haddock
haddock-html: /usr/share/doc/haskell-crypto-pubkey/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
